=======
History
=======

0.1.2dev1 (20217-10-23)
-----------------------
* Added funny name for fortune telling!
* Bump for dev version.

0.1.2beta1 (2017-10-22)
-----------------------
* Choose a random site then display the horoscope given by that site.
* Two sites at the moment: `astrology <https://astrology.com>`_ `ganeshaspeaks <https://www.ganeshaspeaks.com>`_
* From now on, I'll be releasing a *beta* version of ``0.1.2``, and will release ``0.1.3`` as soon as I get things done.

0.1.2 (2017-10-22)
------------------
* Add the supposed functionality.

    ::

    $ pytuneteller horoscope <sign>

0.1.1 (2017-10-21)
------------------

* First release on PyPI. Actually, this is the second release. I had some failures while releasing 0.1.0 and decided to delete it. So yeah, now this is it!
